.. currentmodule:: pyvisco

#############
API Reference
#############

.. automodule:: pyvisco
   :members:

.. autosummary::
    :toctree: _autosummary
    :recursive:

    load
    master
    opt
    out
    prony 
    shift
    styles
    verify
    inter